/****************************************************************/
/* Farbmacher et al, 2017; Increasing the credibility of the twin birth instrument */
/****************************************************************/


clear all
set mem 15000m
set more off



cd "T:\new 2014_12_09"

* Clean, select and re-label variables in the multi-generational register
use flergen_2007, clear

dis _N
keep moder_lopnrfk fader_lopnrfk barn_lopnrfk kon fodelsear fodelseman fodelsearfar fodelsearmor ordnrmor
destring moder_lopnrfk, replace
destring fodelsearmor, replace
destring fader_lopnrfk, replace
destring fodelsearfar, replace
destring barn_lopnrfk, replace
destring fodelsear, replace
destring fodelseman, replace
gen parentsunknown=(moder_lopnrfk ==. & fader_lopnrfk ==.)
drop if moder_lopnrfk ==. & fader_lopnrfk == . 
drop parentsunknown
recode kon (2 = 0)
rename kon boy
rename moder_lopnrfk motherid
rename fader_lopnrfk fatherid
rename barn_lopnrfk id								
rename fodelsear yob
rename fodelseman mob
rename ordnrmor birthorder
gen fatheryob=fodelsearfar
gen motheryob=fodelsearmor
gen female=1-boy
drop boy
foreach x in motherid fatherid id yob mob female fatheryob motheryob birthorder {
	label variable `x' ""
}
compress
drop birthorder

* Dataset with mothers only (wide format)
dis _N
drop if motherid == .
gen multi_yob =  fodelsearmor	
drop fodelsearfar fodelsearmor
rename id child_id
bysort motherid child_id: drop if _n>1 & child_id != .	// remove duplicates 
drop fatherid 
rename motherid id
sort id yob	

drop if yob>1991						
bysort id: gen nr = _n 
save _tt, replace										// remove observations with incorrect birthyearinformation
bysort id: keep if multi_yob != multi_yob[1] 			
keep id
bysort id: keep if _n == 1
merge 1:m id using _tt	
drop if _merge == 3
drop _merge
drop multi_yob

bysort id: egen kids_in_1991=total(yob<=1991)

drop fatheryob
reshape wide child_id yob mob female , i(id) j(nr)			// Wide format 
compress

//generate samesex indicator
gen samesex = female1*female2 + (1-female1)*(1-female2)

//generate indicator for more than twins (twin birth at first birth)
gen morethantwins1st=0
local j=1
local k=`j'+1
local m=`j'+2
replace morethantwins1st=1 if yob`j'==yob`k' & yob`k'==yob`m' & mob`j'==mob`k' & mob`k'==mob`m' & yob`j'!=.	

//generate twin indicator (twin birth at first birth)
gen twin1st=0
gen samesex_twin1st=0
gen sexcomp_twins1st=.
local j=1
local k=`j'+1 
replace twin1st=1 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=.
replace samesex_twin1st=1 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'==female`k'
replace sexcomp_twins1st=1 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'==female`k' & female`j'==0		//two boys
replace sexcomp_twins1st=2 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'==female`k' & female`j'==1		//two girls
replace sexcomp_twins1st=3 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'!=female`k'						//mixed

//generate indicator for more than twins (twin birth at second birth)
gen morethantwins2nd=0
local j=2
local k=`j'+1
local m=`j'+2
replace morethantwins2nd=1 if yob`j'==yob`k' & yob`k'==yob`m' & mob`j'==mob`k' & mob`k'==mob`m' & yob`j'!=.	

//generate twin indicator (twin birth at second birth)
gen twin2nd=0
replace twin2nd=. if kids_in_1991==1

gen sexcomp_twins2nd=.
local j=2
local k=`j'+1 
replace twin2nd=1 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=.

replace sexcomp_twins2nd=1 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'==female`k' & female`j'==0		//two boys
replace sexcomp_twins2nd=2 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'==female`k' & female`j'==1		//two girls
replace sexcomp_twins2nd=3 if yob`j'==yob`k' & mob`j'==mob`k' & yob`j'!=. & female`j'!=female`k'						//mixed

****

cap label def sexcomp_twins 1 "two boys" 2 "two girls" 3 "mixed"
label val sexcomp_twins1st sexcomp_twins
label val sexcomp_twins2nd sexcomp_twins  

assert yob1!=.
assert yob1<=yob2 if yob2!=.
assert yob2<=yob3 if yob2!=. & yob3!=.	
assert yob1<=yob2
assert yob1<=yob3
assert yob1<=yob4
assert yob1<=yob5

rename yob1 born1_yob
rename yob2 born2_yob
rename yob3 born3_yob

set more off
drop yob*
drop  mob* child_id*

drop if born1_yob==.


save bcertificates_1991.dta, replace



